@@ -1,3 +1,52 @@
+#' Trains and tests a multivariate survival model
+#' 
+#' Trains a model on training datasets. Predicts the risk score for all the
+#' training & datasets, independently. This function also predicts the risk
+#' score for combined training datasets cohort and validation datasets cohort.
+#' The risk score estimation is done by multivariate models fit by
+#' \code{fit.survivalmodel}. The function also predicts risk scores for each of
+#' the \code{top.n.features} independently.
+#' 
+#' 
+#' @param data.directory Path to the directory containing datasets as specified
+#' by \code{feature.selection.datasets}, \code{training.datasets},
+#' \code{validation.datasets}
+#' @param output.directory Path to the output folder where intermediate and
+#' results files will be saved
+#' @param feature.selection.datasets A vector containing names of datasets used
+#' for feature selection in function \code{derive.network.features()}
+#' @param feature.selection.p.threshold One of the P values that were used for
+#' feature selection in function \code{derive.network.features()}. This
+#' function does not support vector of P values as used in
+#' \code{derive.network.features()} for performance reasons
+#' @param training.datasets A vector containing names of training datasets
+#' @param validation.datasets A vector containing names of validation datasets
+#' @param top.n.features A numeric value specifying how many top ranked
+#' features will be used for univariate survival modelling
+#' @param models A character vector specifying which of the models ('1' = N+E,
+#' '2' = N, '3' = E) to run
+#' @param learning.algorithms A character vector specifying which learning
+#' algorithm to be used for model fitting and feature selection. Defaults to
+#' c('backward', 'forward'). Available options are: c('backward', 'forward',
+#' 'glm')
+#' @param alpha.glm A numeric vector specifying elastic-net mixing parameter
+#' alpha, with range alpha raning from [0,1]. 1 for LASSO (default) and 0 for
+#' ridge. For multiple values of alpha, most optimal value is selected through
+#' cross validation on training set
+#' @param k.fold.glm A numeric value specifying k-fold cross validation if glm
+#' was chosen in \code{learning.algorithms}
+#' @param seed.cv.glm A numeric value specifying seed for k-fold cross
+#' validation if glm was chosen in \code{learning.algorithms}
+#' @param cores.glm An integer value specifying number of cores to be used for
+#' glm if it was chosen in \code{learning.algorithms}
+#' @return The output files are stored under \code{output.directory}/output/
+#' @author Syed Haider & Vincent Stimper
+#' @keywords survival
+#' @examples
+#' 
+#' # see package's main documentation
+#' 
+#' @export create.classifier.multivariate
 create.classifier.multivariate <- function(data.directory = ".", output.directory = ".", feature.selection.datasets = NULL, feature.selection.p.threshold = 0.05, training.datasets = NULL, validation.datasets = NULL, top.n.features = 25, models = c("1", "2", "3"), learning.algorithms = c("backward", "forward"), alpha.glm = c(1), k.fold.glm = 10, seed.cv.glm = 51214, cores.glm = 1) {
 
 	# sanity checks
@@ -140,7 +189,7 @@ create.classifier.multivariate <- function(data.directory = ".", output.director
 					next;
 					}
 				# fail to converge case
-				if (c("Class", "Mode") %in% names(model.summary) 
+				if ("Class" %in% names(model.summary) && "Mode" %in% names(model.summary) 
 					&& model.summary[["Class"]] == "NULL" && model.summary[["Mode"]] == "NULL") {
 					next;
 					}
